# Contributing

## Feedback and suggestions

The best place for feedback and suggestions is [in
discussions](https://github.com/davep/textual-fspicker/discussions). If it seems like
something that makes sense for the library I'll turn it into an issue from
there.

Be sure to [have a look over the TODO
issues](https://github.com/davep/textual-fspicker/issues?q=is%3Aissue+is%3Aopen+label%3ATODO)
before leaving a request, it might be I'm already planning on implementing
whatever it is you're asking for.

## Bugs

Please report any bugs [as an issue](https://github.com/davep/textual-fspicker/issues).
When doing so, please
provide as much detail as possible, include things like library version,
operating system, some details of the environment, etc.

## Pull requests

Pull requests are very welcome; but when making one I suggest the following:

- Check merged/closed or open pull requests to ensure you're not duplicating
  effort.
- Check previous [discussions](https://github.com/davep/textual-fspicker/discussions)
  to see if the change you're making has been discussed before, or is under
  discussion at the moment.
- Check closed and open [issues](https://github.com/davep/textual-fspicker/issues) to
  see if the change you're making has been discussed before, or is under
  discussion at the moment.
- For any non-trivial PR I'd suggest starting a
  [discussion](https://github.com/davep/textual-fspicker/discussions) first to
  propose and review the change you want to make.
- If a PR was made using some form of LLM or "AI", **PLEASE DECLARE IT AS
  SUCH**. Please note that I'm highly likely to reject any PR made in such a
  way for various reasons relating to licensing problems and how
  maintainable the code likely won't be.

[//]: # (CONTRIBUTING.md ends here)
